@@ -205,8 +205,7 @@ class KeyBlocking(BaseBlocking):
         the identifiers of the records of the both sets for this value.
     """
 
-    def __init__(self, ref_attr_index, target_attr_index,
-                 callback, ignore_none=False):
+    def __init__(self, ref_attr_index, target_attr_index, callback, ignore_none=False):
         super(KeyBlocking, self).__init__(ref_attr_index, target_attr_index)
         self.callback = callback
         self.ignore_none = ignore_none
@@ -250,10 +249,12 @@ class KeyBlocking(BaseBlocking):
 
 
 class SoundexBlocking(KeyBlocking):
-
-    def __init__(self, ref_attr_index, target_attr_index, language='french',):
-        super(SoundexBlocking, self).__init__(ref_attr_index, target_attr_index,
-                                              partial(soundexcode, language=language))
+    def __init__(
+        self, ref_attr_index, target_attr_index, language="french",
+    ):
+        super(SoundexBlocking, self).__init__(
+            ref_attr_index, target_attr_index, partial(soundexcode, language=language)
+        )
 
 
 ###############################################################################
@@ -263,8 +264,7 @@ class NGramBlocking(BaseBlocking):
     """ This blocking technique is based on a a n-gram key.
     """
 
-    def __init__(self, ref_attr_index, target_attr_index,
-                 ngram_size=2, depth=2):
+    def __init__(self, ref_attr_index, target_attr_index, ngram_size=2, depth=2):
         super(NGramBlocking, self).__init__(ref_attr_index, target_attr_index)
         self.ngram_size = ngram_size
         self.depth = depth
@@ -278,7 +278,7 @@ class NGramBlocking(BaseBlocking):
             cur_dict = cur_index
             text = r[attr_index]
             for i in range(self.depth):
-                ngram = text[i * self.ngram_size:(i + 1) * self.ngram_size]
+                ngram = text[i * self.ngram_size : (i + 1) * self.ngram_size]
                 if i < self.depth - 1:
                     cur_dict = cur_dict.setdefault(ngram, {})
             cur_dict.setdefault(ngram, []).append((ind, r[0]))
@@ -296,8 +296,7 @@ class NGramBlocking(BaseBlocking):
             if key in target_cur_dict:
                 if isinstance(sub_dict, dict):
                     # There is another dict layer
-                    for block1, block2 in self._iter_dict(
-                            sub_dict, target_cur_dict[key]):
+                    for block1, block2 in self._iter_dict(sub_dict, target_cur_dict[key]):
                         yield block1, block2
                 else:
                     # This is a list
@@ -313,8 +312,7 @@ class NGramBlocking(BaseBlocking):
                           and containts the indexes of the record in the
                           corresponding dataset.
         """
-        for block1, block2 in self._iter_dict(
-                self.reference_index, self.target_index):
+        for block1, block2 in self._iter_dict(self.reference_index, self.target_index):
             if block1 and block2:
                 yield block1, block2
 
@@ -333,13 +331,8 @@ class SortedNeighborhoodBlocking(BaseBlocking):
     (or blocking key), that will be used to divide the datasets.
     """
 
-    def __init__(self, ref_attr_index, target_attr_index,
-                 key_func=lambda x: x, window_width=20):
-        super(
-            SortedNeighborhoodBlocking,
-            self).__init__(
-            ref_attr_index,
-            target_attr_index)
+    def __init__(self, ref_attr_index, target_attr_index, key_func=lambda x: x, window_width=20):
+        super(SortedNeighborhoodBlocking, self).__init__(ref_attr_index, target_attr_index)
         self.key_func = key_func
         self.window_width = window_width
         self.sorted_dataset = None
@@ -347,10 +340,12 @@ class SortedNeighborhoodBlocking(BaseBlocking):
     def _fit(self, refset, targetset):
         """ Fit a dataset in an index using the callback
         """
-        self.sorted_dataset = [((ind, r[0]), r[self.ref_attr_index], 0)
-                               for ind, r in enumerate(refset)]
-        self.sorted_dataset.extend([((ind, r[0]), r[self.target_attr_index], 1)
-                                    for ind, r in enumerate(targetset)])
+        self.sorted_dataset = [
+            ((ind, r[0]), r[self.ref_attr_index], 0) for ind, r in enumerate(refset)
+        ]
+        self.sorted_dataset.extend(
+            [((ind, r[0]), r[self.target_attr_index], 1) for ind, r in enumerate(targetset)]
+        )
         self.sorted_dataset.sort(key=lambda x: self.key_func(x[1]))
 
     def _iter_blocks(self):
@@ -360,12 +355,13 @@ class SortedNeighborhoodBlocking(BaseBlocking):
             # Only keep reference set record
             if dset == 1:
                 continue
-            block1 = [rid, ]
-            minind = (ind - self.window_width)
+            block1 = [
+                rid,
+            ]
+            minind = ind - self.window_width
             minind = minind if minind >= 0 else 0
-            maxind = (ind + self.window_width + 1)
-            block2 = [ri for ri, re, d in self.sorted_dataset[minind:maxind]
-                      if d == 1]
+            maxind = ind + self.window_width + 1
+            block2 = [ri for ri, re, d in self.sorted_dataset[minind:maxind] if d == 1]
             if block1 and block2:
                 yield (block1, block2)
 
@@ -400,22 +396,20 @@ class MergeBlocking(BaseBlocking):
         self.merged_dataset = None
         self.other_dataset = None
         if ref_attr_index is None and target_attr_index is None:
-            raise ValueError('At least one of ref_attr_index or target_attr_index '
-                             'should not be None')
+            raise ValueError(
+                "At least one of ref_attr_index or target_attr_index " "should not be None"
+            )
 
     def _fit(self, refset, targetset):
         """ Fit a dataset in an index using the callback
         """
         if self.ref_attr_index is not None:
             # Merge refset
-            self.merged_dataset = self._merge_dataset(
-                refset, self.ref_attr_index)
-            self.other_dataset = [(ind, r[0])
-                                  for ind, r in enumerate(targetset)]
+            self.merged_dataset = self._merge_dataset(refset, self.ref_attr_index)
+            self.other_dataset = [(ind, r[0]) for ind, r in enumerate(targetset)]
         else:
             # Merge targetset
-            self.merged_dataset = self._merge_dataset(
-                targetset, self.target_attr_index)
+            self.merged_dataset = self._merge_dataset(targetset, self.target_attr_index)
             self.other_dataset = [(ind, r[0]) for ind, r in enumerate(refset)]
 
     def _merge_dataset(self, dataset, attr_index):
@@ -427,12 +421,13 @@ class MergeBlocking(BaseBlocking):
             if record[attr_index] not in merged_dataset_dict:
                 # Create new entry
                 merged_dataset_dict[record[attr_index]] = (ind, record, score)
-            elif (record[attr_index] in merged_dataset_dict
-                  and merged_dataset_dict[record[attr_index]][2] < score):
+            elif (
+                record[attr_index] in merged_dataset_dict
+                and merged_dataset_dict[record[attr_index]][2] < score
+            ):
                 # Change current score
                 merged_dataset_dict[record[attr_index]] = (ind, record, score)
-        return [(ind, r[0])
-                for ind, r, score in itervalues(merged_dataset_dict)]
+        return [(ind, r[0]) for ind, r, score in itervalues(merged_dataset_dict)]
 
     def _iter_blocks(self):
         """ Iterator over the different possible blocks.
@@ -463,6 +458,7 @@ class KmeansBlocking(BaseBlocking):
         self.kmeans = None
         self.predicted = None
         from sklearn import cluster
+
         self.cluster_class = cluster.KMeans
 
     def _fit(self, refset, targetset):
@@ -470,10 +466,9 @@ class KmeansBlocking(BaseBlocking):
         """
         # If an element is None (missing), use instead the identity element.
         # The identity element is defined as the 0-vector
-        idelement = tuple(
-            [0 for _ in xrange(len(refset[0][self.ref_attr_index]))])
+        idelement = tuple([0 for _ in xrange(len(refset[0][self.ref_attr_index]))])
         # We assume here that there are at least 2 elements in the refset
-        n_clusters = self.n_clusters or (len(refset) / 10 or len(refset) / 2)
+        n_clusters = self.n_clusters or (len(refset) // 10 or len(refset) // 2)
         try:
             kmeans = self.cluster_class(n_clusters=n_clusters)
         except TypeError:
@@ -482,8 +477,9 @@ class KmeansBlocking(BaseBlocking):
         kmeans.fit([elt[self.ref_attr_index] or idelement for elt in refset])
         self.kmeans = kmeans
         # Predict on targetset
-        self.predicted = self.kmeans.predict([elt[self.target_attr_index]
-                                              or idelement for elt in targetset])
+        self.predicted = self.kmeans.predict(
+            [elt[self.target_attr_index] or idelement for elt in targetset]
+        )
 
     def _iter_blocks(self):
         """ Iterator over the different possible blocks.
@@ -495,8 +491,7 @@ class KmeansBlocking(BaseBlocking):
                           and containts the indexes of the record in the
                           corresponding dataset.
         """
-        n_clusters = self.kmeans.n_clusters if hasattr(
-            self.kmeans, 'n_clusters') else self.kmeans.k
+        n_clusters = self.kmeans.n_clusters if hasattr(self.kmeans, "n_clusters") else self.kmeans.k
         neighbours = [[[], []] for _ in xrange(n_clusters)]
         for ind, li in enumerate(self.predicted):
             neighbours[li][1].append(self.targetids[ind])
@@ -532,20 +527,19 @@ class KdTreeBlocking(BaseBlocking):
         """
         firstelement = refset[0][self.ref_attr_index]
         self.nb_elements = len(refset)
-        idsize = len(firstelement) if isinstance(
-            firstelement, (tuple, list)) else 1
+        idsize = len(firstelement) if isinstance(firstelement, (tuple, list)) else 1
         idelement = (0,) * idsize
         # KDTree is expecting a two-dimensional array
         if idsize == 1:
-            self.reftree = KDTree(
-                [(elt[self.ref_attr_index],) or idelement for elt in refset])
+            self.reftree = KDTree([(elt[self.ref_attr_index],) or idelement for elt in refset])
             self.targettree = KDTree(
-                [(elt[self.target_attr_index],) or idelement for elt in targetset])
+                [(elt[self.target_attr_index],) or idelement for elt in targetset]
+            )
         else:
-            self.reftree = KDTree(
-                [elt[self.ref_attr_index] or idelement for elt in refset])
+            self.reftree = KDTree([elt[self.ref_attr_index] or idelement for elt in refset])
             self.targettree = KDTree(
-                [elt[self.target_attr_index] or idelement for elt in targetset])
+                [elt[self.target_attr_index] or idelement for elt in targetset]
+            )
 
     def _iter_blocks(self):
         """ Iterator over the different possible blocks.
@@ -557,13 +551,14 @@ class KdTreeBlocking(BaseBlocking):
                           and containts the indexes of the record in the
                           corresponding dataset.
         """
-        extraneighbours = self.reftree.query_ball_tree(
-            self.targettree, self.threshold)
+        extraneighbours = self.reftree.query_ball_tree(self.targettree, self.threshold)
         neighbours = []
         for ind in xrange(self.nb_elements):
             if not extraneighbours[ind]:
                 continue
-            _ref = [self.refids[ind], ]
+            _ref = [
+                self.refids[ind],
+            ]
             _target = [self.targetids[v] for v in extraneighbours[ind]]
             neighbours.append((_ref, _target))
         for block1, block2 in neighbours:
@@ -585,13 +580,8 @@ class MinHashingBlocking(BaseBlocking):
     """ A blocking technique based on MinHashing
     """
 
-    def __init__(self, ref_attr_index, target_attr_index,
-                 threshold=0.1, kwordsgram=1, siglen=200):
-        super(
-            MinHashingBlocking,
-            self).__init__(
-            ref_attr_index,
-            target_attr_index)
+    def __init__(self, ref_attr_index, target_attr_index, threshold=0.1, kwordsgram=1, siglen=200):
+        super(MinHashingBlocking, self).__init__(ref_attr_index, target_attr_index)
         self.threshold = threshold
         self.kwordsgram = kwordsgram
         self.siglen = siglen
@@ -602,11 +592,13 @@ class MinHashingBlocking(BaseBlocking):
         """ Find the blocking using minhashing
         """
         # If an element is None (missing), use instead the identity element.
-        idelement = ''
-        self.minhasher.train([elt[self.ref_attr_index] or idelement for elt in refset] +
-                             [elt[self.target_attr_index]
-                                 or idelement for elt in targetset],
-                             self.kwordsgram, self.siglen)
+        idelement = ""
+        self.minhasher.train(
+            [elt[self.ref_attr_index] or idelement for elt in refset]
+            + [elt[self.target_attr_index] or idelement for elt in targetset],
+            self.kwordsgram,
+            self.siglen,
+        )
         self.nb_elements = len(refset)
 
     def _iter_blocks(self):
@@ -625,8 +617,7 @@ class MinHashingBlocking(BaseBlocking):
             neighbours.append([[], []])
             for i in data:
                 if i >= self.nb_elements:
-                    neighbours[-1][1].append(self.targetids[i -
-                                                            self.nb_elements])
+                    neighbours[-1][1].append(self.targetids[i - self.nb_elements])
                 else:
                     neighbours[-1][0].append(self.refids[i])
             if len(neighbours[-1][0]) == 0 or len(neighbours[-1][1]) == 0:
@@ -664,10 +655,7 @@ class PipelineBlocking(BaseBlocking):
 
     def _fit(self, refset, targetset):
         """ Internal fit of the pipeline """
-        self._recursive_fit(
-            refset, targetset, range(
-                len(refset)), range(
-                len(targetset)), 0)
+        self._recursive_fit(refset, targetset, range(len(refset)), range(len(targetset)), 0)
 
     def _recursive_fit(self, refset, targetset, ref_index, target_index, ind):
         """ Recursive fit of the blockings.
@@ -677,30 +665,23 @@ class PipelineBlocking(BaseBlocking):
             # There are other blockings after this one
             blocking = self.blockings[ind]
             blocking.cleanup()
-            blocking.fit([refset[i] for i in ref_index],
-                         [targetset[i] for i in target_index])
+            blocking.fit([refset[i] for i in ref_index], [targetset[i] for i in target_index])
             for block1, block2 in blocking.iter_indice_blocks():
                 ind_block1 = [ref_index[i] for i in block1]
                 ind_block2 = [target_index[i] for i in block2]
                 if self.collect_stats:
-                    self.stats.setdefault(
-                        ind, []).append(
-                        (len(block1), len(block2)))
-                self._recursive_fit(
-                    refset, targetset, ind_block1, ind_block2, ind + 1)
+                    self.stats.setdefault(ind, []).append((len(block1), len(block2)))
+                self._recursive_fit(refset, targetset, ind_block1, ind_block2, ind + 1)
         else:
             # This is the final blocking
             blocking = self.blockings[ind]
             blocking.cleanup()
-            blocking.fit([refset[i] for i in ref_index],
-                         [targetset[i] for i in target_index])
+            blocking.fit([refset[i] for i in ref_index], [targetset[i] for i in target_index])
             for block1, block2 in blocking.iter_blocks():
                 ind_block1 = [(ref_index[i], _id) for i, _id in block1]
                 ind_block2 = [(target_index[i], _id) for i, _id in block2]
                 if self.collect_stats:
-                    self.stats.setdefault(
-                        ind, []).append(
-                        (len(block1), len(block2)))
+                    self.stats.setdefault(ind, []).append((len(block1), len(block2)))
                 self.stored_blocks.append((ind_block1, ind_block2))
 
     def _iter_blocks(self):
