@@ -23,10 +23,11 @@ from six.moves import xrange
 
 try:
     from dateutil import parser as dateparser
+
     DATEUTIL_ENABLED = True
 except ImportError:
     DATEUTIL_ENABLED = False
-from scipy import matrix, empty
+from scipy import array, empty
 
 from nazca.utils.normalize import tokenize
 
@@ -34,8 +35,14 @@ from nazca.utils.normalize import tokenize
 ###############################################################################
 # UTILITY FUNCTIONS ###########################################################
 ###############################################################################
-def cdist(distance_callback, refset, targetset, matrix_normalized=False,
-          ref_indexes=None, target_indexes=None):
+def cdist(
+    distance_callback,
+    refset,
+    targetset,
+    matrix_normalized=False,
+    ref_indexes=None,
+    target_indexes=None,
+):
     """ Compute the metric matrix, given two datasets and a metric
 
     Parameters
@@ -52,10 +59,7 @@ def cdist(distance_callback, refset, targetset, matrix_normalized=False,
     """
     ref_indexes = ref_indexes or xrange(len(refset))
     target_indexes = target_indexes or xrange(len(targetset))
-    distmatrix = empty(
-        (len(ref_indexes),
-         len(target_indexes)),
-        dtype='float32')
+    distmatrix = empty((len(ref_indexes), len(target_indexes)), dtype="float32")
     for i, iref in enumerate(ref_indexes):
         for j, jref in enumerate(target_indexes):
             d = 1
@@ -85,10 +89,10 @@ def _handlespaces(stra, strb, distance, tokenizer=None, **kwargs):
         Return 4
     """
 
-    if ' ' not in stra:
-        stra += ' '
-    if ' ' not in strb:
-        strb += ' '
+    if " " not in stra:
+        stra += " "
+    if " " not in strb:
+        strb += " "
 
     toka = tokenize(stra, tokenizer)
     tokb = tokenize(strb, tokenizer)
@@ -97,13 +101,12 @@ def _handlespaces(stra, strb, distance, tokenizer=None, **kwargs):
     if len(toka) != len(tokb):
         mint = toka if len(toka) < len(tokb) else tokb
         maxt = toka if len(toka) > len(tokb) else tokb
-        mint.extend(['' for i in range(len(maxt) - len(mint))])
+        mint.extend(["" for i in range(len(maxt) - len(mint))])
 
     listmatrix = []
     for i in xrange(len(toka)):
-        listmatrix.append([distance(toka[i], tokb[j], **kwargs)
-                           for j in xrange(len(tokb))])
-    m = matrix(listmatrix)
+        listmatrix.append([distance(toka[i], tokb[j], **kwargs) for j in xrange(len(tokb))])
+    m = array(listmatrix)
     minlist = [m[i, :].min() for i in xrange(m.shape[0])]
     minlist.extend([m[:, i].min() for i in xrange(m.shape[1])])
     return max(minlist)
@@ -143,7 +146,7 @@ def levenshtein(stra, strb, tokenizer=None):
         If spaces are found in stra or strb, this method returns
             _handlespaces(stra, strb, levenshtein)
     """
-    if ' ' in stra or ' ' in strb:
+    if " " in stra or " " in strb:
         return _handlespaces(stra, strb, levenshtein, tokenizer)
 
     lenb = len(strb)
@@ -159,7 +162,7 @@ def levenshtein(stra, strb, tokenizer=None):
     return thisrow[lenb - 1]
 
 
-def soundexcode(word, language='french'):
+def soundexcode(word, language="french"):
     """ Return the Soundex code of the word ``word``
         For more information about soundex code see wiki_
 
@@ -171,31 +174,55 @@ def soundexcode(word, language='french'):
             _handlespaces(stra, strb), soundex, language=language)
     """
 
-    vowels = 'AEHIOUWY'
-    if language.lower() == 'french':
-        consonnantscode = {'B': '1', 'P': '1',
-                           'C': '2', 'K': '2', 'Q': '2',
-                           'D': '3', 'T': '3',
-                           'L': '4',
-                           'M': '5', 'N': '5',
-                           'R': '6',
-                           'G': '7', 'J': '7',
-                           'X': '8', 'Z': '8', 'S': '8',
-                           'F': '9', 'V': '9'
-                           }
-    elif language.lower() == 'english':
-        consonnantscode = {'B': '1', 'F': '1', 'P': '1', 'V': '1',
-                           'C': '2', 'G': '2', 'J': '2', 'K': '2',
-                           'Q': '2', 'S': '2', 'X': '2', 'Z': '2',
-                           'D': '3', 'T': '3',
-                           'L': '4',
-                           'M': '5', 'N': '5',
-                           'R': '6'
-                           }
+    vowels = "AEHIOUWY"
+    if language.lower() == "french":
+        consonnantscode = {
+            "B": "1",
+            "P": "1",
+            "C": "2",
+            "K": "2",
+            "Q": "2",
+            "D": "3",
+            "T": "3",
+            "L": "4",
+            "M": "5",
+            "N": "5",
+            "R": "6",
+            "G": "7",
+            "J": "7",
+            "X": "8",
+            "Z": "8",
+            "S": "8",
+            "F": "9",
+            "V": "9",
+        }
+    elif language.lower() == "english":
+        consonnantscode = {
+            "B": "1",
+            "F": "1",
+            "P": "1",
+            "V": "1",
+            "C": "2",
+            "G": "2",
+            "J": "2",
+            "K": "2",
+            "Q": "2",
+            "S": "2",
+            "X": "2",
+            "Z": "2",
+            "D": "3",
+            "T": "3",
+            "L": "4",
+            "M": "5",
+            "N": "5",
+            "R": "6",
+        }
     else:
-        raise NotImplementedError('Soundex code is not supported (yet ?) for'
-                                  'this language (%s). '
-                                  'Supported languages are french and english' % language)
+        raise NotImplementedError(
+            "Soundex code is not supported (yet ?) for"
+            "this language (%s). "
+            "Supported languages are french and english" % language
+        )
     word = word.strip().upper()
     code = word[0]
     # After this ``for`` code is
@@ -206,35 +233,37 @@ def soundexcode(word, language='french'):
     for i in xrange(1, len(word)):
         if word[i] in vowels:
             continue
-        if word[i - 1] not in vowels and \
-           consonnantscode[word[i]] == consonnantscode.get(code[-1], ''):
+        if word[i - 1] not in vowels and consonnantscode[word[i]] == consonnantscode.get(
+            code[-1], ""
+        ):
             continue
-        if i + 2 < len(word) and word[i + 1] in 'WH' and \
-           consonnantscode[word[i]] == consonnantscode.get(word[i + 2], ''):
+        if (
+            i + 2 < len(word)
+            and word[i + 1] in "WH"
+            and consonnantscode[word[i]] == consonnantscode.get(word[i + 2], "")
+        ):
             continue
         code += word[i]
         if len(code) > 4:
             break
 
     # Replace according to the codes
-    code = code[0] + ''.join([consonnantscode[c] for c in code[1:]])
+    code = code[0] + "".join([consonnantscode[c] for c in code[1:]])
     # First four letters, completed by zeros
-    return code[:4] + '0' * (4 - len(code))
+    return code[:4] + "0" * (4 - len(code))
 
 
-def soundex(stra, strb, language='french', tokenizer=None):
+def soundex(stra, strb, language="french", tokenizer=None):
     """ Return the 1/0 distance between the soundex code of stra and strb.
         0 means they have the same code, 1 they don't
     """
-    if ' ' in stra or ' ' in strb:
-        return _handlespaces(stra, strb, soundex,
-                             tokenizer=tokenizer, language=language)
-    return 0 if (soundexcode(stra, language) ==
-                 soundexcode(strb, language)) else 1
+    if " " in stra or " " in strb:
+        return _handlespaces(stra, strb, soundex, tokenizer=tokenizer, language=language)
+    return 0 if (soundexcode(stra, language) == soundexcode(strb, language)) else 1
 
 
 def jaccard(stra, strb, tokenizer=None):
-    """ Return the jaccard distance between stra and strb, condering the tokens
+    r""" Return the jaccard distance between stra and strb, condering the tokens
         set of stra and strb. If no tokenizer is given, it use if
         alignement.normalize.tokenize's default one.
 
@@ -247,7 +276,7 @@ def jaccard(stra, strb, tokenizer=None):
 
 
 def generic_jaccard(seta, setb):
-    """ Return the jaccard distance between two sets A and B.
+    r""" Return the jaccard distance between two sets A and B.
 
         J(A, B) = (A \cap B)/(A \cup B)
         d(A, B) = 1 - J(A, B)
@@ -260,7 +289,6 @@ def generic_jaccard(seta, setb):
         return 1.0
 
 
-
 def difflib_match(stra, strb):
     """ Approximate matching.
     Extract of SequenceMatched documentation
@@ -278,33 +306,46 @@ def difflib_match(stra, strb):
 # TEMPORAL DISTANCES ##########################################################
 ###############################################################################
 if DATEUTIL_ENABLED:
+
     class FrenchParserInfo(dateparser.parserinfo):
         """ Inherit of the dateutil.parser.parserinfo and translate the english
             dependant variables into french.
         """
 
-        HMS = [(u'h', u'heure', u'heures'),
-               (u'm', u'minute', u'minutes'),
-               (u's', u'seconde', u'seconde'), ]
-        JUMP = [u' ', u'.', u',', u';', u'-', u'/', u"'",
-                u'a', u'le', u'et', u'er']
-        MONTHS = [(u'Jan', u'Janvier'), (u'Fev', u'Fevrier'),
-                  (u'Mar', u'Mars'), (u'Avr', u'Avril'), (u'Mai', u'Mai'),
-                  (u'Jun', u'Juin'), (u'Jui', u'Juillet'),
-                  (u'Aou', u'Aout'), (u'Sep', u'Septembre'),
-                  (u'Oct', u'Octobre'), (u'Nov', u'Novembre'),
-                  (u'Dec', u'Decembre')]
-        PERTAIN = [u'de']
-        WEEKDAYS = [(u'Lun', u'Lundi'),
-                    (u'Mar', u'Mardi'),
-                    (u'Mer', u'Mercredi'),
-                    (u'Jeu', u'Jeudi'),
-                    (u'Ven', u'Vendredi'),
-                    (u'Sam', u'Samedi'),
-                    (u'Dim', u'Dimanche')]
+        HMS = [
+            (u"h", u"heure", u"heures"),
+            (u"m", u"minute", u"minutes"),
+            (u"s", u"seconde", u"seconde"),
+        ]
+        JUMP = [u" ", u".", u",", u";", u"-", u"/", u"'", u"a", u"le", u"et", u"er"]
+        MONTHS = [
+            (u"Jan", u"Janvier"),
+            (u"Fev", u"Fevrier"),
+            (u"Mar", u"Mars"),
+            (u"Avr", u"Avril"),
+            (u"Mai", u"Mai"),
+            (u"Jun", u"Juin"),
+            (u"Jui", u"Juillet"),
+            (u"Aou", u"Aout"),
+            (u"Sep", u"Septembre"),
+            (u"Oct", u"Octobre"),
+            (u"Nov", u"Novembre"),
+            (u"Dec", u"Decembre"),
+        ]
+        PERTAIN = [u"de"]
+        WEEKDAYS = [
+            (u"Lun", u"Lundi"),
+            (u"Mar", u"Mardi"),
+            (u"Mer", u"Mercredi"),
+            (u"Jeu", u"Jeudi"),
+            (u"Ven", u"Vendredi"),
+            (u"Sam", u"Samedi"),
+            (u"Dim", u"Dimanche"),
+        ]
 
-    def temporal(stra, strb, granularity=u'days', parserinfo=FrenchParserInfo,
-                 dayfirst=True, yearfirst=False):
+    def temporal(
+        stra, strb, granularity=u"days", parserinfo=FrenchParserInfo, dayfirst=True, yearfirst=False
+    ):
         """ Return the distance between two strings (read as dates).
 
             ``granularity`` can be either ``days`` or ``months`` or ``years``
@@ -317,14 +358,12 @@ if DATEUTIL_ENABLED:
             Neither stra nor strb can have accent. Clean it before.
         """
 
-        datea = dateparser.parse(stra, parserinfo=parserinfo(dayfirst,
-                                                             yearfirst), fuzzy=True)
-        dateb = dateparser.parse(strb, parserinfo=parserinfo(dayfirst,
-                                                             yearfirst), fuzzy=True)
+        datea = dateparser.parse(stra, parserinfo=parserinfo(dayfirst, yearfirst), fuzzy=True)
+        dateb = dateparser.parse(strb, parserinfo=parserinfo(dayfirst, yearfirst), fuzzy=True)
         diff = datea - dateb
-        if granularity.lower() == 'years':
+        if granularity.lower() == "years":
             return abs(diff.days / 365.25)
-        if granularity.lower() == 'months':
+        if granularity.lower() == "months":
             return abs(diff.days / 30.5)
         return abs(diff.days)
 
@@ -332,8 +371,7 @@ if DATEUTIL_ENABLED:
 ###############################################################################
 # GEOGRAPHICAL DISTANCES ######################################################
 ###############################################################################
-def geographical(pointa, pointb, in_radians=False, planet_radius=6371009,
-                 units='m'):
+def geographical(pointa, pointb, in_radians=False, planet_radius=6371009, units="m"):
     """ Return the geographical distance between two points.
 
         Both points must be tuples (latitude, longitude)
@@ -345,7 +383,7 @@ def geographical(pointa, pointb, in_radians=False, planet_radius=6371009,
 
         - `units` can be 'm' (meters) or 'km' (kilometers)
     """
-    if units not in ('m', 'km'):
+    if units not in ("m", "km"):
         raise ValueError("unsupported units, should be in m or km")
     pointa = (float(pointa[0]), float(pointa[1]))
     pointb = (float(pointb[0]), float(pointb[1]))
@@ -359,9 +397,8 @@ def geographical(pointa, pointb, in_radians=False, planet_radius=6371009,
         difflong *= pi / 180.0
         meanlat *= pi / 180.0
 
-    coef = 1. if units == 'm' else 0.001
-    return coef * planet_radius * \
-        sqrt(difflat**2 + (cos(meanlat) * difflong)**2)
+    coef = 1.0 if units == "m" else 0.001
+    return coef * planet_radius * sqrt(difflat ** 2 + (cos(meanlat) * difflong) ** 2)
 
 
 ###############################################################################
@@ -371,8 +408,14 @@ class BaseProcessing(object):
     """ A processing object used to provide an abstraction over the different
     distance functions, and help building Nazca process. """
 
-    def __init__(self, ref_attr_index=None, target_attr_index=None,
-                 distance_callback=euclidean, weight=1, matrix_normalized=False):
+    def __init__(
+        self,
+        ref_attr_index=None,
+        target_attr_index=None,
+        distance_callback=euclidean,
+        weight=1,
+        matrix_normalized=False,
+    ):
         """ Initiate the BaseProcessing
 
         Parameters
@@ -410,7 +453,7 @@ class BaseProcessing(object):
         if isinstance(index, tuple) and len(index) == 2:
             return (record[index[0]], record[index[1]])
         else:
-            return (record[index] if index is not None else record)
+            return record[index] if index is not None else record
 
     def distance(self, reference_record, target_record):
         """ Compute the distance between two records
@@ -422,8 +465,10 @@ class BaseProcessing(object):
         target_record: a record (tuple/list of values) of the target dataset.
 
         """
-        return self.distance_callback(self.build_record(reference_record, self.ref_attr_index),
-                                      self.build_record(target_record, self.target_attr_index))
+        return self.distance_callback(
+            self.build_record(reference_record, self.ref_attr_index),
+            self.build_record(target_record, self.target_attr_index),
+        )
 
     def cdist(self, refset, targetset, ref_indexes=None, target_indexes=None):
         """ Compute the metric matrix, given two datasets and a metric
@@ -440,9 +485,14 @@ class BaseProcessing(object):
         A distance matrix, of shape (len(refset), len(targetset))
         with the distance of each element in it.
         """
-        return cdist(self.distance, refset, targetset,
-                     matrix_normalized=self.matrix_normalized,
-                     ref_indexes=ref_indexes, target_indexes=target_indexes)
+        return cdist(
+            self.distance,
+            refset,
+            targetset,
+            matrix_normalized=self.matrix_normalized,
+            ref_indexes=ref_indexes,
+            target_indexes=target_indexes,
+        )
 
     def pdist(self, dataset):
         """ Compute the upper triangular matrix in a way similar
@@ -478,95 +528,132 @@ class ExactMatchProcessing(BaseProcessing):
     """ A processing based on the exact match (1 if a==b, 0 elsewise)
     """
 
-    def __init__(self, ref_attr_index=None, target_attr_index=None,
-                 tokenizer=None, weight=1, matrix_normalized=False):
-        super(ExactMatchProcessing, self).__init__(ref_attr_index,
-                                                   target_attr_index,
-                                                   exact_match,
-                                                   weight, matrix_normalized)
+    def __init__(
+        self,
+        ref_attr_index=None,
+        target_attr_index=None,
+        tokenizer=None,
+        weight=1,
+        matrix_normalized=False,
+    ):
+        super(ExactMatchProcessing, self).__init__(
+            ref_attr_index, target_attr_index, exact_match, weight, matrix_normalized
+        )
 
 
 class LevenshteinProcessing(BaseProcessing):
     """ A processing based on the levenshtein distance.
     """
 
-    def __init__(self, ref_attr_index=None, target_attr_index=None,
-                 tokenizer=None, weight=1, matrix_normalized=False):
-        distance_callback = partial(levenshtein,
-                                    tokenizer=tokenizer)
-        super(LevenshteinProcessing, self).__init__(ref_attr_index,
-                                                    target_attr_index,
-                                                    distance_callback,
-                                                    weight, matrix_normalized)
+    def __init__(
+        self,
+        ref_attr_index=None,
+        target_attr_index=None,
+        tokenizer=None,
+        weight=1,
+        matrix_normalized=False,
+    ):
+        distance_callback = partial(levenshtein, tokenizer=tokenizer)
+        super(LevenshteinProcessing, self).__init__(
+            ref_attr_index, target_attr_index, distance_callback, weight, matrix_normalized
+        )
 
 
 class GeographicalProcessing(BaseProcessing):
     """ A processing based on the geographical distance.
     """
 
-    def __init__(self, ref_attr_index=None, target_attr_index=None,
-                 in_radians=False, planet_radius=6371009, units='m', weight=1,
-                 matrix_normalized=False):
-        distance_callback = partial(geographical, in_radians=in_radians,
-                                    planet_radius=planet_radius, units=units)
-        super(GeographicalProcessing, self).__init__(ref_attr_index,
-                                                     target_attr_index,
-                                                     distance_callback,
-                                                     weight, matrix_normalized)
+    def __init__(
+        self,
+        ref_attr_index=None,
+        target_attr_index=None,
+        in_radians=False,
+        planet_radius=6371009,
+        units="m",
+        weight=1,
+        matrix_normalized=False,
+    ):
+        distance_callback = partial(
+            geographical, in_radians=in_radians, planet_radius=planet_radius, units=units
+        )
+        super(GeographicalProcessing, self).__init__(
+            ref_attr_index, target_attr_index, distance_callback, weight, matrix_normalized
+        )
 
 
 class SoundexProcessing(BaseProcessing):
     """ A processing based on the soundex distance.
     """
 
-    def __init__(self, ref_attr_index=None, target_attr_index=None,
-                 tokenizer=None, weight=1, language='french', matrix_normalized=False):
-        distance_callback = partial(
-            soundex, language=language, tokenizer=tokenizer)
-        super(SoundexProcessing, self).__init__(ref_attr_index,
-                                                target_attr_index,
-                                                distance_callback,
-                                                weight, matrix_normalized)
+    def __init__(
+        self,
+        ref_attr_index=None,
+        target_attr_index=None,
+        tokenizer=None,
+        weight=1,
+        language="french",
+        matrix_normalized=False,
+    ):
+        distance_callback = partial(soundex, language=language, tokenizer=tokenizer)
+        super(SoundexProcessing, self).__init__(
+            ref_attr_index, target_attr_index, distance_callback, weight, matrix_normalized
+        )
 
 
 class JaccardProcessing(BaseProcessing):
     """ A processing based on the jaccard distance.
     """
 
-    def __init__(self, ref_attr_index=None, target_attr_index=None,
-                 tokenizer=None, weight=1, matrix_normalized=False):
+    def __init__(
+        self,
+        ref_attr_index=None,
+        target_attr_index=None,
+        tokenizer=None,
+        weight=1,
+        matrix_normalized=False,
+    ):
         distance_callback = partial(jaccard, tokenizer=tokenizer)
-        super(JaccardProcessing, self).__init__(ref_attr_index,
-                                                target_attr_index,
-                                                distance_callback,
-                                                weight, matrix_normalized)
+        super(JaccardProcessing, self).__init__(
+            ref_attr_index, target_attr_index, distance_callback, weight, matrix_normalized
+        )
 
 
 class DifflibProcessing(BaseProcessing):
     """ A processing based on the difflib distance.
     """
 
-    def __init__(self, ref_attr_index=None, target_attr_index=None,
-                 weight=1, matrix_normalized=False):
-        super(DifflibProcessing, self).__init__(ref_attr_index,
-                                                target_attr_index,
-                                                difflib_match,
-                                                weight, matrix_normalized)
+    def __init__(
+        self, ref_attr_index=None, target_attr_index=None, weight=1, matrix_normalized=False
+    ):
+        super(DifflibProcessing, self).__init__(
+            ref_attr_index, target_attr_index, difflib_match, weight, matrix_normalized
+        )
 
 
 if DATEUTIL_ENABLED:
+
     class TemporalProcessing(BaseProcessing):
         """ A processing based on the temporal distance.
         """
 
-        def __init__(self, ref_attr_index=None, target_attr_index=None,
-                     granularity=u'days', parserinfo=FrenchParserInfo,
-                     dayfirst=True, yearfirst=False,
-                     weight=1, matrix_normalized=False):
-            distance_callback = partial(temporal, granularity=granularity,
-                                        parserinfo=parserinfo,
-                                        dayfirst=dayfirst, yearfirst=yearfirst)
-            super(TemporalProcessing, self).__init__(ref_attr_index,
-                                                     target_attr_index,
-                                                     distance_callback,
-                                                     weight, matrix_normalized)
+        def __init__(
+            self,
+            ref_attr_index=None,
+            target_attr_index=None,
+            granularity=u"days",
+            parserinfo=FrenchParserInfo,
+            dayfirst=True,
+            yearfirst=False,
+            weight=1,
+            matrix_normalized=False,
+        ):
+            distance_callback = partial(
+                temporal,
+                granularity=granularity,
+                parserinfo=parserinfo,
+                dayfirst=dayfirst,
+                yearfirst=yearfirst,
+            )
+            super(TemporalProcessing, self).__init__(
+                ref_attr_index, target_attr_index, distance_callback, weight, matrix_normalized
+            )
