@@ -17,6 +17,7 @@
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 from __future__ import absolute_import
 import sys
+
 if sys.version_info >= (2, 7):
     import unittest
 else:
@@ -24,7 +25,7 @@ else:
 from functools import partial
 from os import path
 import random
-random.seed(6)  # Make sure tests are repeatable
+from mock import patch
 
 from nazca.utils.normalize import simplify
 from nazca.utils.minhashing import Minlsh, count_vectorizer_func
@@ -34,17 +35,16 @@ TESTDIR = path.dirname(__file__)
 
 
 class MinLSHTest(unittest.TestCase):
-
     def test_iter_wordgrams(self):
-        sentence = 'nom de la rose'
+        sentence = "nom de la rose"
         minlsh = Minlsh()
         results = list(minlsh._iter_wordgrams(sentence, 2))
-        truth = ['nom de', 'nom', 'de la', 'de', 'la rose', 'la', 'rose']
+        truth = ["nom de", "nom", "de la", "de", "la rose", "la", "rose"]
         self.assertEqual(len(results), len(truth))
         self.assertEqual(set(results), set(truth))
 
     def test_iter_wordgrams_sklearn(self):
-        sentences = ('nom de la rose', 'nom de la')
+        sentences = ("nom de la rose", "nom de la")
         tokenizer_func = partial(count_vectorizer_func, min_n=1, max_n=2)
         minlsh = Minlsh(tokenizer_func=tokenizer_func)
         rows, shape = list(minlsh._buildmatrixdocument(sentences, 2))
@@ -53,19 +53,31 @@ class MinLSHTest(unittest.TestCase):
         self.assertEqual(rows[1], [0, 1, 2, 4, 5])
 
     def test_all(self):
-        sentences = [u"Un nuage flotta dans le grand ciel bleu.",
-                     u"Des grands nuages noirs flottent dans le ciel.",
-                     u"Je n'aime pas ce genre de bandes dessinées tristes.",
-                     u"J'aime les bandes dessinées de genre comiques.",
-                     u"Pour quelle occasion vous êtes-vous apprêtée ?",
-                     u"Je les vis ensemble à plusieurs occasions.",
-                     u"Je les ai vus ensemble à plusieurs occasions.",
-                     ]
+        sentences = [
+            u"Un nuage flotta dans le grand ciel bleu.",
+            u"Des grands nuages noirs flottent dans le ciel.",
+            u"Je n'aime pas ce genre de bandes dessinées tristes.",
+            u"J'aime les bandes dessinées de genre comiques.",
+            u"Pour quelle occasion vous êtes-vous apprêtée ?",
+            u"Je les vis ensemble à plusieurs occasions.",
+            u"Je les ai vus ensemble à plusieurs occasions.",
+        ]
         minlsh = Minlsh()
-        # XXX Should works independantly of the seed. Unstability due to the bands number ?
-        minlsh.train((simplify(s, FRENCH_LEMMAS, remove_stopwords=True) for s in sentences), 1, 200)
+
+        # the minhashing function is based on a « hash » function. This hash
+        # function is itself based on two integers randomly chosen in a
+        # given interval. Different runs of this procedure will produce
+        # different results because the hash function will be different.
+        # This is the expected behaviour. Excepted in the tests, where we
+        # need the result to be reproductible. Therefore we patch the
+        # `random.randint` with a fixed-seed version.
+        myrandom = random.Random("spam eggs bacon")
+        with patch("nazca.utils.minhashing.randint", myrandom.randint):
+            minlsh.train(
+                (simplify(s, FRENCH_LEMMAS, remove_stopwords=True) for s in sentences), 1, 200,
+            )
         self.assertEqual(set([(0, 1), (2, 3), (5, 6)]), minlsh.predict(0.4))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
